@@ -6,7 +6,7 @@
 #
 
 package IP::Random;
-$IP::Random::VERSION = '1.004';
+$IP::Random::VERSION = '1.006';
 # ABSTRACT: Generate IP Addresses Randomly
 
 
@@ -46,10 +46,8 @@ sub random_ipv4 ( %args ) {
     $args{rand} //= sub { int( rand( shift() + 1 ) ) };
 
     # Can't have exclude and additional_types_allowed both existing
-    if ( exists( $args{exclude} ) && exists( $args{additional_types_allowed} ) )
-    {
-        croak(  "Cannot define both 'exclude' and "
-              . "'additional_types_allowed' parameters" );
+    if ( exists( $args{exclude} ) && exists( $args{additional_types_allowed} ) ) {
+        croak( "Cannot define both 'exclude' and " . "'additional_types_allowed' parameters" );
     }
 
     # This saves us some later branches
@@ -97,8 +95,8 @@ sub random_ipv4 ( %args ) {
 sub _get_ipv4_excludes( $addl_types ) {
     my @ret = grep {
         my $k = $_;
-        none { $DEFAULT_IPV4_EXCLUDE->{$k} eq $_ } @{ $addl_types }
-    } keys %{ $DEFAULT_IPV4_EXCLUDE };
+        none { $DEFAULT_IPV4_EXCLUDE->{$k} eq $_ } @{$addl_types}
+    } keys %{$DEFAULT_IPV4_EXCLUDE};
 
     return \@ret;
 }
@@ -108,14 +106,14 @@ sub in_ipv4_subnet ( $sub_cidr, $ip ) {
     if ( !defined($sub_cidr) ) { confess("subnet_cidr is not defined"); }
     if ( !defined($ip) )       { confess("ip is not defined"); }
 
-    if ( $sub_cidr !~ m/\A(?:[\d\.]+)(?:\/(?:\d+))?\z/ ) {
+    if ( $sub_cidr !~ m/\A(?:[0-9\.]+)(?:\/(?:[0-9]+))?\z/ ) {
         confess("$sub_cidr is not in the format A.B.C.D/N");
     }
-    my ( $sub_net, $sub_mask ) = $sub_cidr =~ m/\A([\d\.]+)(?:\/(\d+))?\z/ms;
+    my ( $sub_net, $sub_mask ) = $sub_cidr =~ m/\A([0-9\.]+)(?:\/([0-9]+))?\z/ms;
     $sub_mask //= 32;
 
-    my $addr = unpack( 'N', inet_aton( $ip ) );
-    my $sub  = unpack( 'N', inet_aton( $sub_net ) );
+    my $addr = unpack( 'N', inet_aton($ip) );
+    my $sub  = unpack( 'N', inet_aton($sub_net) );
 
     my $mask = 0;
     for ( 1 .. $sub_mask ) {
@@ -127,7 +125,7 @@ sub in_ipv4_subnet ( $sub_cidr, $ip ) {
         return 1;
     }
 
-    return undef;
+    return;
 }
 
 
@@ -149,7 +147,7 @@ IP::Random - Generate IP Addresses Randomly
 
 =head1 VERSION
 
-version 1.004
+version 1.006
 
 =head1 SYNOPSIS
 
@@ -341,7 +339,7 @@ This list contains:
 
 =item 0.0.0.0/8
 
-"This" Network (RFC 1122, Section 3.2.1.3)
+"This" Network (RFC1122, Section 3.2.1.3)
 
 =item 10.0.0.0/8
 
@@ -353,7 +351,7 @@ Shared Address Space (RFC6598)
 
 =item 127.0.0.0/8
 
-Loopback (RFC 1122, Section 3.2.1.3)
+Loopback (RFC1122, Section 3.2.1.3)
 
 =item 169.254.0.0/16
 
@@ -440,7 +438,7 @@ Joelle Maslak <jmaslak@antelope.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Joelle Maslak.
+This software is Copyright (c) 2018 by Joelle Maslak.
 
 This is free software, licensed under:
 
